| Title: | Biosensor Development using Omics Data |
|---|---|
| Description: | A method for the quantitative prediction using omics data. This package provides functions to construct the quantitative prediction model using omics data. |
| Authors: | Takahiko Koizumi, Kenta Suzuki, Yasunori Ichihashi |
| Maintainer: | Takahiko Koizumi <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.1 |
| Built: | 2026-05-16 07:09:33 UTC |
| Source: | https://github.com/takakoizumi/omicsense |